@@ -17,12 +17,5 @@ sed -i /vendored/d Cargo.toml
 
 # avoid pulling in windows-sys for now
 cargo update -p schannel --precise 0.1.19
-
-# pin the dependencies as Debian intended
-cargo update -p ignore --precise 0.4.19
-cargo update -p regex --precise 1.7.0
-cargo update -p proc-macro2 --precise 1.0.49
-cargo update -p termcolor --precise 1.1.3
-cargo update -p git2 --precise 0.16.0
-cargo update -p libgit2-sys --precise 0.14.1+1.5.0
-cargo update -p unicode-bidi --precise 0.3.8
+# the UI tests are targeted at clap/4.0.15
+cargo update -p clap --precise 4.0.15
